@@ -1,10 +1,10 @@
-/* $Id: SUPR0IdcClientComponent.c 118839 2017-10-28 15:14:05Z bird $ */
+/* $Id: SUPR0IdcClientComponent.c 135976 2020-02-04 10:35:17Z bird $ */
 /** @file
  * VirtualBox Support Driver - IDC Client Lib, Component APIs.
  */
 
 /*
- * Copyright (C) 2008-2017 Oracle Corporation
+ * Copyright (C) 2008-2020 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -29,7 +29,7 @@
 *   Header Files                                                                                                                 *
 *********************************************************************************************************************************/
 #include "SUPR0IdcClientInternal.h"
-#include <VBox/err.h>
+#include <iprt/errcore.h>
 
 
 /**
